@@ -1,10 +1,10 @@
 package Net::DNS::RR::RT;
 
 #
-# $Id: RT.pm 1382 2015-08-26 20:39:33Z willem $
+# $Id: RT.pm 1390 2015-09-11 11:42:11Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1382 $)[1];
+$VERSION = (qw$LastChangedRevision: 1390 $)[1];
 
 
 use strict;
@@ -35,16 +35,16 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 	my ( $offset, @opaque ) = @_;
 
-	return '' unless $self->{intermediate};
-	pack 'n a*', $self->preference, $self->{intermediate}->encode( $offset, @opaque );
+	my $intermediate = $self->{intermediate} || return '';
+	pack 'n a*', $self->preference, $intermediate->encode( $offset + 2, @opaque );
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{intermediate};
-	join ' ', $self->preference, $self->{intermediate}->string;
+	my $intermediate = $self->{intermediate} || return '';
+	join ' ', $self->preference, $intermediate->string;
 }
 
 
